Class: AuthorizeNet::API::Transaction

Inherits:
ApiTransaction show all
Defined in:
lib/authorize_net/api/transaction.rb

Constant Summary

Constants inherited from XmlTransaction

XmlTransaction::XML_NAMESPACE

Constants included from TypeConversions

TypeConversions::API_FIELD_PREFIX

Instance Method Summary collapse

Methods inherited from ApiTransaction

#deserialize, #make_request, #send_request, #serialize

Methods inherited from XmlTransaction

#has_response?, #response, #run, #test?, #xml

Methods inherited from Transaction

#fields, #set_address, #set_customer, #set_fields, #set_shipping_address

Methods included from TypeConversions

#boolean_to_value, #date_to_value, #datetime_to_value, #decimal_to_value, #integer_to_value, #to_external_field, #to_internal_field, #to_param, #value_to_boolean, #value_to_date, #value_to_datetime, #value_to_decimal, #value_to_integer

Constructor Details

#initialize(api_login_id, api_transaction_key, options = {}) ⇒ Transaction

Returns a new instance of Transaction.



4
5
6
# File 'lib/authorize_net/api/transaction.rb', line 4

def initialize(, api_transaction_key, options = {})
   super
end

Instance Method Details

#create_customer_profile_from_transaction(request) ⇒ Object

This request enables you to create a customer profile, payment profile, and shipping profile from an existing successful transaction. NOTE: Tokenized transactions (e.g. Apple Pay), or PayPal should not be used to create payment profiles.

See spec/api_spec.rb for usage examples



23
24
25
# File 'lib/authorize_net/api/transaction.rb', line 23

def create_customer_profile_from_transaction(request)
  make_request(request,CreateProfileResponse,Type::API_CREATE_CUSTOMER_PROFILE_FROM_TRANSACTION)
end

#create_transaction(request) ⇒ Object

This request enables you to create a transaction, and optional customer profile. NOTE: Tokenized transactions (e.g. Apple Pay), or PayPal should not be used to create payment profiles.

See spec/api_spec.rb for usage examples



13
14
15
# File 'lib/authorize_net/api/transaction.rb', line 13

def create_transaction(request)  
  make_request(request,CreateTransactionResponse,Type::API_CREATE_TRANSACTION)
end

#delete_customer_profile(request) ⇒ Object

This request enables you to delete a customer profile.

See spec/api_spec.rb for usage examples



30
31
32
# File 'lib/authorize_net/api/transaction.rb', line 30

def delete_customer_profile(request)
  make_request(request,DeleteCustomerProfileResponse,Type::API_DELETE_CUSTOMER_PROFILE)
end